@@ -119,6 +119,11 @@ def test_get_eq_func():
         assert not get_eq_func(t)(None, 1)
         assert get_eq_func(t)(1, 1)
         assert get_eq_func(t)(None, None)
+    t = pa.null()
+    assert get_eq_func(t)("0", "1")
+    assert get_eq_func(t)(None, "1")
+    assert get_eq_func(t)("1", "1")
+    assert get_eq_func(t)(None, None)
     t = pa.string()
     assert not get_eq_func(t)("0", "1")
     assert not get_eq_func(t)(None, "1")
